==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QCameraLocksControl_shell.h <==
#ifndef QCAMERALOCKSCONTROL_SHELL_H
#define QCAMERALOCKSCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcameralockscontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qcamera.h>
#include <QtJambi/RegistryAPI>


class QCameraLocksControl_shell : public QCameraLocksControl, public QtJambiShellInterface
{
public:
    QCameraLocksControl_shell(QObject* parent0 = nullptr);
    ~QCameraLocksControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QCamera::LockStatus lockStatus(QCamera::LockType lock0) const override;
    void searchAndLock(QCamera::LockTypes locks0) override;
    QCamera::LockTypes supportedLocks() const override;
    void timerEvent(QTimerEvent* event0) override;
    void unlock(QCamera::LockTypes locks0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCameraLocksControl_access : public QCameraLocksControl
{
    jint __qt_lockStatus_QCamera_LockType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint lock0) const;
    void __qt_searchAndLock_QCamera_LockTypes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint locks0);
    jint __qt_supportedLocks(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_unlock_QCamera_LockTypes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint locks0);
};

#endif // QCAMERALOCKSCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QCameraLocksControl_shell.h <==
#ifndef QCAMERALOCKSCONTROL_SHELL_H
#define QCAMERALOCKSCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcameralockscontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qcamera.h>
#include <QtJambi/RegistryAPI>


class QCameraLocksControl_shell : public QCameraLocksControl, public QtJambiShellInterface
{
public:
    QCameraLocksControl_shell(QObject* parent0 = nullptr);
    ~QCameraLocksControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QCamera::LockStatus lockStatus(QCamera::LockType lock0) const override;
    void searchAndLock(QCamera::LockTypes locks0) override;
    QCamera::LockTypes supportedLocks() const override;
    void timerEvent(QTimerEvent* event0) override;
    void unlock(QCamera::LockTypes locks0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCameraLocksControl_access : public QCameraLocksControl
{
    jint __qt_lockStatus_QCamera_LockType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint lock0) const;
    void __qt_searchAndLock_QCamera_LockTypes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint locks0);
    jint __qt_supportedLocks_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_unlock_QCamera_LockTypes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint locks0);
};

#endif // QCAMERALOCKSCONTROL_SHELL_H
